@@ -1,186 +1,14 @@
 from copy import deepcopy
 from motor.motor_asyncio import AsyncIOMotorClient as MongoClient  # 代码提示
-
 from arts.vtype import uniset, empset, SysEmpty, ToolPool, OrmIndexError
-
-
-class Factory:
-    _variable = True
-
-    def __init__(self, where):
-        if where is not empset:
-            where = where or uniset
-        self.where = where
-        self._variable = False
-
-    def __setattr__(self, name, value):
-        assert self._variable
-        object.__setattr__(self, name, value)
-    
-    def __bool__(self): return True  # 下面有一个 where or Factory(uniset)
-
-    def _deepcopy(self, obj):
-        if obj in (uniset, empset):
-            return obj
-        return deepcopy(obj)
-
-    def __and__(self, obj):  # 交集
-        a = self._deepcopy(self.where)
-        b = self._deepcopy(obj.where)
-        if a is uniset: return Factory(b)
-        if b is uniset: return Factory(a)
-        if a and b:  # a和b有可能是empset
-            if set(a) & set(b):
-                return Factory({'$and': [a, b]})
-            return Factory({**a, **b})
-        return Factory(empset)
-    
-    def __or__(self, obj):  # 并集
-        a = self._deepcopy(self.where)
-        b = self._deepcopy(obj.where)
-        if a is empset: return Factory(b)
-        if b is empset: return Factory(a)
-        if a is uniset or b is uniset:
-            return Factory(uniset)
-        return Factory({'$or': [a, b]})
-    
-    def __sub__(self, obj): return self & (~ obj)  # 差集
-
-    def __invert__(self):  # 补集
-        w = self.where
-        if w is uniset: return Factory(empset)
-        if w is empset: return Factory(uniset)
-        return Factory({'$nor': [w]})
-    
-    def ParseWhere(self):
-        where  = self._deepcopy(self.where)
-        if where is uniset: return {}
-        if where is empset: return {'$and': [{'a':1}, {'a':2}]}
-        return where
-
-class moBase():
-    def __init__(self, *lis, **dic):
-        self.lis = lis
-        self.dic = dic
-
-class containAll(moBase): ...
-class containAny(moBase): ...
-class containNo(moBase): ...
-class isin(moBase): ...
-class notin(moBase): ...
-def re(s, i=False):
-    if i:
-        return {'$regex': s, '$options': 'i'}
-    return {'$regex': s}
-
-
-class Filter():
-    _variable = True
-
-    def __init__(self, field):
-        self.field = field
-        self._variable = False
-    
-    def __setattr__(self, name, value):
-        assert self._variable
-        object.__setattr__(self, name, value)
-    
-    def __getattr__(self, name): return Filter(f"{self.field}.{name}")
-    def __lt__(self, obj): return Factory({self.field: {'$lt': obj}})  # <
-    def __le__(self, obj): return Factory({self.field: {'$lte': obj}})  # <=
-    def __gt__(self, obj): return Factory({self.field: {'$gt': obj}})  # >
-    def __ge__(self, obj): return Factory({self.field: {'$gte': obj}})  # >=
-    def __ne__(self, obj): return Factory({self.field: {'$ne': obj}})  # !=
-
-    def __eq__(self, obj):
-        if isinstance(obj, containAll):
-            lis = obj.lis
-            if len(lis) == 1: return Factory({self.field: {'$elemMatch':{'$eq':lis[0]}}})
-            if len(lis) > 1: return Factory({'$and': [{self.field: {'$elemMatch':{'$eq':x}}} for x in set(lis)]})
-            return Factory(uniset)
-        
-        elif isinstance(obj, containAny):
-            lis = obj.lis
-            if len(lis) == 1: return Factory({self.field: {'$elemMatch':{'$eq':lis[0]}}})
-            if len(lis) > 1: return Factory({'$or': [{self.field: {'$elemMatch':{'$eq':x}}} for x in set(lis)]})
-            return Factory(empset)
-        
-        elif isinstance(obj, containNo):
-            lis = obj.lis
-            if lis: return Factory({'$nor': [{self.field: {'$elemMatch':{'$eq':x}}} for x in set(lis)]})
-            return Factory(uniset)
-        
-        elif isinstance(obj, isin):
-            lis = obj.lis
-            if not lis: return Factory(empset)
-            if len(lis) == 1: return Factory({self.field: lis[0]})
-            return Factory({self.field: {'$in': lis}})
-        
-        elif isinstance(obj, notin):
-            lis = obj.lis
-            if not lis: return Factory(uniset)
-            if len(lis) == 1: return Factory({self.field: {'$ne': lis[0]}})
-            return Factory({self.field: {'$nin': lis}})
-        
-        return Factory({self.field: obj})
-
-class upList(): ...
-class mup:
-    class push(upList):  # 添加
-        name = '$push'
-        def __init__(self, *vs):
-            self.value = {"$each":list(vs)}
-    
-    class add(upList):  # 不存在时才添加
-        name = '$addToSet'
-        def __init__(self, *vs):
-            self.value = {"$each":list(vs)}
-
-    class inc(upList):  # 自增:inc(1), 自减:inc(-1)
-        name = '$inc'
-        def __init__(self, value):
-            self.value = value
-
-    class pull(upList):  # 从数组field内删除一个等于value值
-        name = '$pull'
-        def __init__(self, value):
-            self.value = value
-
-    class rename(upList):  # 修改字段名称
-        name = '$rename'
-        def __init__(self, value):
-            self.value = value
-
-    class _(upList):  # 删除键
-        name = '$unset'
-        value = 1
-    unset = delete = _()
-
-    class _(upList):
-        name = '$pop'
-        def __init__(self, value):
-            self.value = value
-    popfirst = _(-1)  # 删除数组第1个元素, 和Python相反, -1代表最前面
-    poplast = _(1)  # 删除数组最后1个元素
+from arts.mongo._core import Factory, containAll, containAny, containNo, isin, notin, re
+from arts.mongo._core import Filter, mc, makeSlice, allColumns, upList, mup
 
 
 repairUpsert = False
 # pymongo官方bug
 # cannot infer query fields to set, path 'a' is matched twice, full error: {'index': 0, 'code': 54, 'errmsg': "cannot infer query fields to set, path 'a' is matched twice"}
 
-
-class allColumns: ...
-
-
-class makeSlice():
-    def __init__(self, func, *vs, **kvs):
-        self.func = func
-        self.vs = vs
-        self.kvs = kvs
-    def __getitem__(self, key):
-        return self.func(key, *self.vs, **self.kvs)
-    
-
 class sheetORM():
     _variable = True
 
@@ -539,13 +367,4 @@ class ORM():
             assert key.start is key.stop is key.step is None
             return [dbORM(connPool=self.connPool, dbName=x) for x in self.getDbNames()]
         else:
-            raise TypeError(key)
-
-
-class MongoColumn():
-    _id = None  # 字段提示
-    def __getattribute__(self, field):
-        return Filter(field=field)
-    __getitem__ = __getattribute__
-
-mc = MongoColumn()  # 已被sheetORM.update和sheetORM.delete调用
\ No newline at end of file
+            raise TypeError(key)
\ No newline at end of file
