@@ -368,14 +368,14 @@ class sheetORM():
 
     async def insert(self, data):
         if type(data) is dict:
-            cols = data.keys()
+            cols = [f"{x}" for x in data]
             sql = f"insert into {self.sheetName}({', '.join(cols)}) values ({', '.join(('%s',)*len(cols))})"
             rdata, cursor = await self.execute(sql, tuple(data.values()))
             return cursor  # cursor.rowcount, cursor.lastrowid
         else:
             cols = set()
             for x in data: cols |= set(x)
-            cols = list(cols)
+            cols = [f"{x}" for x in cols]
             sql = f"insert into {self.sheetName}({', '.join(cols)}) values ({', '.join(('%s',)*len(cols))})"
             data = tuple(tuple(x.get(k) for k in cols) for x in data)
             r, cursor = await self.executemany(sql, data)
@@ -583,24 +583,28 @@ class sheetORM():
         r = obj['conn'].close()
         return r or True
 
-class MysqlColumn():
-    id = None  # 字段提示
-    def __getattribute__(self, field):
-        return Filter(field=field)
-    __getitem__ = __getattribute__
 
-mc = MysqlColumn()
+def creat_Filter(cls_or_self, field) -> Filter:
+    return Filter(field=field)
 
-class MysqlFunc():
+class McType(type):
+    __getattribute__ = creat_Filter
+    __getitem__ = creat_Filter
+
+class mc(object, metaclass=McType):
+    id = None  # 预设字段提示
+
+def _builtFunc(cls_or_self, func):
+    def builtFunc(*fields):
+        return Filter(field=f"{func}({', '.join(fields)})")
+    return builtFunc
+
+class MfType(type):
+    __getattribute__ = _builtFunc
+
+class mf(object, metaclass=MfType):
     # 函数名提示
     year = day = month = week = hour = None
     md5 = None
     round = ceil = floor = abs = least = greatest = sign = pi = None
-    curdate = curtime = utcdata = utctime = now = localtime = None
-    
-    def __getattribute__(self, func):
-        def builtFunc(*fields):
-            return Filter(field=f"{func}({', '.join(fields)})")
-        return builtFunc
-
-mf = MysqlFunc()
\ No newline at end of file
+    curdate = curtime = utcdata = utctime = now = localtime = None
\ No newline at end of file
