@@ -73,56 +73,60 @@ def re(s, i=False):
         return {'$regex': s, '$options': 'i'}
     return {'$regex': s}
 
+def GetFiField(obj:'Filter'):
+    return object.__getattribute__(obj, 'field')
 
 class Filter():
     _variable = True
 
-    def __init__(self, field):
+    def __init__(self, field:str):
         self.field = field
         self._variable = False
     
     def __setattr__(self, name, value):
-        assert self._variable
+        assert object.__getattribute__(self, '_variable')
         object.__setattr__(self, name, value)
     
-    def __getattr__(self, name): return Filter(f"{self.field}.{name}")
-    def __lt__(self, obj): return Factory({self.field: {'$lt': obj}})  # <
-    def __le__(self, obj): return Factory({self.field: {'$lte': obj}})  # <=
-    def __gt__(self, obj): return Factory({self.field: {'$gt': obj}})  # >
-    def __ge__(self, obj): return Factory({self.field: {'$gte': obj}})  # >=
-    def __ne__(self, obj): return Factory({self.field: {'$ne': obj}})  # !=
+    def __getattribute__(self, field): return Filter(f"{GetFiField(self)}.{field}")
+    __getitem__ = __getattribute__
+
+    def __lt__(self, obj): return Factory({GetFiField(self): {'$lt': obj}})  # <
+    def __le__(self, obj): return Factory({GetFiField(self): {'$lte': obj}})  # <=
+    def __gt__(self, obj): return Factory({GetFiField(self): {'$gt': obj}})  # >
+    def __ge__(self, obj): return Factory({GetFiField(self): {'$gte': obj}})  # >=
+    def __ne__(self, obj): return Factory({GetFiField(self): {'$ne': obj}})  # !=
 
     def __eq__(self, obj):
         if isinstance(obj, containAll):
             lis = obj.lis
-            if len(lis) == 1: return Factory({self.field: {'$elemMatch':{'$eq':lis[0]}}})
-            if len(lis) > 1: return Factory({'$and': [{self.field: {'$elemMatch':{'$eq':x}}} for x in set(lis)]})
+            if len(lis) == 1: return Factory({GetFiField(self): {'$elemMatch':{'$eq':lis[0]}}})
+            if len(lis) > 1: return Factory({'$and': [{GetFiField(self): {'$elemMatch':{'$eq':x}}} for x in set(lis)]})
             return Factory(uniset)
         
         elif isinstance(obj, containAny):
             lis = obj.lis
-            if len(lis) == 1: return Factory({self.field: {'$elemMatch':{'$eq':lis[0]}}})
-            if len(lis) > 1: return Factory({'$or': [{self.field: {'$elemMatch':{'$eq':x}}} for x in set(lis)]})
+            if len(lis) == 1: return Factory({GetFiField(self): {'$elemMatch':{'$eq':lis[0]}}})
+            if len(lis) > 1: return Factory({'$or': [{GetFiField(self): {'$elemMatch':{'$eq':x}}} for x in set(lis)]})
             return Factory(empset)
         
         elif isinstance(obj, containNo):
             lis = obj.lis
-            if lis: return Factory({'$nor': [{self.field: {'$elemMatch':{'$eq':x}}} for x in set(lis)]})
+            if lis: return Factory({'$nor': [{GetFiField(self): {'$elemMatch':{'$eq':x}}} for x in set(lis)]})
             return Factory(uniset)
         
         elif isinstance(obj, isin):
             lis = obj.lis
             if not lis: return Factory(empset)
-            if len(lis) == 1: return Factory({self.field: lis[0]})
-            return Factory({self.field: {'$in': lis}})
+            if len(lis) == 1: return Factory({GetFiField(self): lis[0]})
+            return Factory({GetFiField(self): {'$in': lis}})
         
         elif isinstance(obj, notin):
             lis = obj.lis
             if not lis: return Factory(uniset)
-            if len(lis) == 1: return Factory({self.field: {'$ne': lis[0]}})
-            return Factory({self.field: {'$nin': lis}})
+            if len(lis) == 1: return Factory({GetFiField(self): {'$ne': lis[0]}})
+            return Factory({GetFiField(self): {'$nin': lis}})
         
-        return Factory({self.field: obj})
+        return Factory({GetFiField(self): obj})
 
 
 class makeSlice():
@@ -550,10 +554,12 @@ class ORM():
             raise TypeError(key)
 
 
-class MongoColumn():
-    _id = None  # 字段提示
-    def __getattribute__(self, field):
-        return Filter(field=field)
-    __getitem__ = __getattribute__
+def creat_Filter(cls_or_self, field) -> Filter:
+    return Filter(field=field)
 
-mc = MongoColumn()  # 已被sheetORM.update和sheetORM.delete调用
\ No newline at end of file
+class McType(type):
+    __getattribute__ = creat_Filter
+    __getitem__ = creat_Filter
+
+class mc(object, metaclass=McType):
+    _id = None  # 预设字段提示
\ No newline at end of file
