@@ -4,7 +4,7 @@ from pathlib import Path
 from ._envname import envname
 
 
-def _parsecmd():
+def _ParseCmd():
     kws = sys.argv[1:]
     if kws:
         kw = kws[0].lower()
